/*     */ package com.st.stm32cube.ide.mcu.debug.launch;
/*     */ 
/*     */ import com.google.gson.Gson;
/*     */ import com.google.gson.JsonSyntaxException;
/*     */ import com.st.stm32cube.common.logger.MCULoggerPlugin;
/*     */ import java.nio.file.InvalidPathException;
/*     */ import java.nio.file.Paths;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Optional;
/*     */ import java.util.stream.Collectors;
/*     */ import org.eclipse.cdt.debug.core.CDebugUtils;
/*     */ import org.eclipse.cdt.launch.LaunchUtils;
/*     */ import org.eclipse.cdt.managedbuilder.core.IConfiguration;
/*     */ import org.eclipse.cdt.managedbuilder.core.IManagedBuildInfo;
/*     */ import org.eclipse.cdt.managedbuilder.core.ManagedBuildManager;
/*     */ import org.eclipse.cdt.managedbuilder.macros.BuildMacroException;
/*     */ import org.eclipse.core.resources.IProject;
/*     */ import org.eclipse.core.resources.IResource;
/*     */ import org.eclipse.core.resources.ResourcesPlugin;
/*     */ import org.eclipse.core.runtime.CoreException;
/*     */ import org.eclipse.core.runtime.IPath;
/*     */ import org.eclipse.core.runtime.Path;
/*     */ import org.eclipse.core.variables.VariablesPlugin;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class LoadListInfo
/*     */ {
/*  39 */   private ArrayList<LoadListItem> fItems = new ArrayList<>();
/*     */ 
/*     */   
/*     */   public ArrayList<LoadListItem> getInternalItems() {
/*  43 */     return this.fItems;
/*     */   }
/*     */   
/*     */   public Optional<LoadListItem> getPrimaryItem() {
/*     */     int i;
/*  48 */     for (i = this.fItems.size(); i > 0; i--) {
/*  49 */       LoadListItem item = this.fItems.get(i - 1);
/*  50 */       if (item.shouldDownload().booleanValue()) {
/*  51 */         return Optional.of(item);
/*     */       }
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/*  57 */     for (i = this.fItems.size(); i > 0; i--) {
/*  58 */       LoadListItem item = this.fItems.get(i - 1);
/*  59 */       if (item.shouldLoadSymbols().booleanValue()) {
/*  60 */         return Optional.of(item);
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/*  65 */     return Optional.empty();
/*     */   }
/*     */   
/*     */   public List<LoadListItem> getAdditionalItems() {
/*  69 */     LoadListItem primaryItem = getPrimaryItem().orElse(null);
/*  70 */     return (List<LoadListItem>)this.fItems.stream().filter(item -> (item != paramLoadListItem1)).collect(Collectors.toList());
/*     */   }
/*     */   
/*     */   public String asJSON() {
/*  74 */     return (new Gson()).toJson(this);
/*     */   }
/*     */   
/*     */   public static Optional<LoadListInfo> parseLoadListInfo(Map<String, Object> attributes) {
/*  78 */     String loadListJson = (String)CDebugUtils.getAttribute(attributes, "com.st.stm32cube.ide.mcu.debug.launch.loadList", "");
/*  79 */     if (loadListJson != null && !loadListJson.isEmpty()) {
/*     */       try {
/*  81 */         LoadListInfo info = (LoadListInfo)(new Gson()).fromJson(loadListJson, LoadListInfo.class);
/*  82 */         return Optional.ofNullable(info);
/*  83 */       } catch (JsonSyntaxException e) {
/*  84 */         MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to parse load list information: " + loadListJson);
/*     */       } 
/*     */     }
/*  87 */     return Optional.empty();
/*     */   }
/*     */ 
/*     */   
/*     */   public static class LoadListItem
/*     */   {
/*     */     private Boolean fIsFromMainTab;
/*     */     
/*     */     private String fPath;
/*     */     
/*     */     private Integer fDownloadAddress;
/*     */     
/*     */     private Integer fSymbolAddress;
/*     */     
/*     */     private String fProjectName;
/*     */     
/*     */     private String fBuildConfigId;
/*     */     
/*     */     private Boolean fUseActiveBuildConfig;
/*     */     
/*     */     private Boolean fPerformBuild;
/*     */     
/*     */     private Boolean fDownload;
/*     */     private Boolean fLoadSymbols;
/*     */     
/*     */     public LoadListItem(boolean isFromMainTab, String path, Integer downloadAddress, Integer symbolAddress, String projectName, String buildConfigId, Boolean performBuild, Boolean download, Boolean loadSymbols) {
/* 113 */       this.fIsFromMainTab = Boolean.valueOf(isFromMainTab);
/* 114 */       this.fPath = path;
/* 115 */       this.fDownloadAddress = downloadAddress;
/* 116 */       this.fSymbolAddress = symbolAddress;
/* 117 */       this.fProjectName = projectName;
/* 118 */       this.fBuildConfigId = buildConfigId;
/* 119 */       this.fPerformBuild = performBuild;
/* 120 */       this.fDownload = download;
/* 121 */       this.fLoadSymbols = loadSymbols;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public LoadListItem(boolean isFromMainTab, String path, Integer downloadAddress, Integer symbolAddress, String projectName, Boolean useActiveBuildConfig, Boolean performBuild, Boolean download, Boolean loadSymbols) {
/* 133 */       this.fIsFromMainTab = Boolean.valueOf(isFromMainTab);
/* 134 */       this.fPath = path;
/* 135 */       this.fDownloadAddress = downloadAddress;
/* 136 */       this.fSymbolAddress = symbolAddress;
/* 137 */       this.fProjectName = projectName;
/* 138 */       this.fUseActiveBuildConfig = useActiveBuildConfig;
/* 139 */       this.fPerformBuild = performBuild;
/* 140 */       this.fDownload = download;
/* 141 */       this.fLoadSymbols = loadSymbols;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public String getAbsolutePath() {
/* 149 */       if (this.fUseActiveBuildConfig != null && this.fUseActiveBuildConfig.booleanValue()) {
/* 150 */         IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(this.fProjectName);
/* 151 */         if (project != null) {
/* 152 */           IManagedBuildInfo info = ManagedBuildManager.getBuildInfo((IResource)project);
/* 153 */           if (info != null) {
/* 154 */             IConfiguration config = info.getDefaultConfiguration();
/* 155 */             if (config != null) {
/*     */               try {
/* 157 */                 String path = ManagedBuildManager.getBuildMacroProvider().resolveValue("${PWD}/${BuildArtifactFilePrefix}${BuildArtifactFileName}", "", " ", 3, config);
/* 158 */                 return Path.fromOSString(path).toOSString();
/* 159 */               } catch (BuildMacroException e1) {
/* 160 */                 MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e1, "Failed to resolve program path from build configuration " + config.getName() + " for project " + project.getName());
/*     */               } 
/*     */             }
/*     */           } 
/*     */         } 
/*     */         
/* 166 */         return "";
/*     */       } 
/* 168 */       return getAbsolutePath(this.fProjectName, this.fPath);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public static String getAbsolutePath(String projectName, String path) {
/* 178 */       String resolvedPath = path;
/*     */       try {
/* 180 */         resolvedPath = VariablesPlugin.getDefault().getStringVariableManager().performStringSubstitution(resolvedPath);
/* 181 */       } catch (CoreException e) {
/* 182 */         MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to resolve path '" + path + "'");
/*     */       } 
/*     */ 
/*     */       
/*     */       try {
/* 187 */         if (Paths.get(resolvedPath, new String[0]).isAbsolute()) {
/* 188 */           return resolvedPath;
/*     */         }
/* 190 */       } catch (InvalidPathException e) {
/* 191 */         MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", e, "Invalid path '" + resolvedPath + "'");
/*     */       } 
/*     */       
/* 194 */       if (projectName != null && !projectName.trim().isEmpty() && resolvedPath != null && !resolvedPath.isEmpty()) {
/* 195 */         IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(projectName);
/* 196 */         if (project != null) {
/* 197 */           return LaunchUtils.toAbsoluteProgramPath(project, (IPath)new Path(resolvedPath)).toOSString();
/*     */         }
/*     */       } 
/*     */       
/* 201 */       return resolvedPath;
/*     */     }
/*     */     
/*     */     public Boolean isFromMainTab() {
/* 205 */       return this.fIsFromMainTab;
/*     */     }
/*     */     
/*     */     public String getPath() {
/* 209 */       if (this.fUseActiveBuildConfig != null && this.fUseActiveBuildConfig.booleanValue()) {
/* 210 */         String programPath = getAbsolutePath();
/*     */         
/* 212 */         if (!programPath.isEmpty()) {
/*     */           
/* 214 */           IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(this.fProjectName);
/* 215 */           if (project != null) {
/* 216 */             IPath path = Path.fromOSString(programPath);
/* 217 */             path = path.makeRelativeTo(project.getLocation());
/* 218 */             return path.toOSString();
/*     */           } 
/*     */         } 
/*     */ 
/*     */         
/* 223 */         return programPath;
/*     */       } 
/* 225 */       return this.fPath;
/*     */     }
/*     */     
/*     */     public Integer getDownloadAddress() {
/* 229 */       return this.fDownloadAddress;
/*     */     }
/*     */     
/*     */     public Integer getSymbolAddress() {
/* 233 */       return this.fSymbolAddress;
/*     */     }
/*     */     
/*     */     public String getProjectName() {
/* 237 */       return this.fProjectName;
/*     */     }
/*     */     
/*     */     public boolean useActiveBuildConfig() {
/* 241 */       if (this.fUseActiveBuildConfig != null) {
/* 242 */         return this.fUseActiveBuildConfig.booleanValue();
/*     */       }
/* 244 */       return false;
/*     */     }
/*     */     
/*     */     public String getBuildConfigId() {
/* 248 */       if (useActiveBuildConfig()) {
/* 249 */         IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(this.fProjectName);
/* 250 */         if (project != null) {
/* 251 */           IManagedBuildInfo buildInfo = ManagedBuildManager.getBuildInfo((IResource)project);
/* 252 */           if (buildInfo != null) {
/* 253 */             IConfiguration config = buildInfo.getDefaultConfiguration();
/* 254 */             if (config != null) {
/* 255 */               return config.getId();
/*     */             }
/*     */           } 
/*     */         } 
/* 259 */         return null;
/*     */       } 
/* 261 */       return this.fBuildConfigId;
/*     */     }
/*     */     
/*     */     public Boolean shouldPerformBuild() {
/* 265 */       return this.fPerformBuild;
/*     */     }
/*     */     
/*     */     public Boolean shouldDownload() {
/* 269 */       return this.fDownload;
/*     */     }
/*     */     
/*     */     public Boolean shouldLoadSymbols() {
/* 273 */       return this.fLoadSymbols;
/*     */     }
/*     */     
/*     */     public void setPath(String path) {
/* 277 */       this.fPath = path;
/*     */     }
/*     */     
/*     */     public void setProjectName(String projectName) {
/* 281 */       this.fProjectName = projectName;
/*     */     }
/*     */     
/*     */     public boolean isValid() {
/* 285 */       if (isFromMainTab().booleanValue() && (
/* 286 */         this.fPath == null || this.fPath.trim().isEmpty()) && (this.fProjectName == null || this.fProjectName.trim().isEmpty())) {
/* 287 */         return false;
/*     */       }
/*     */       
/* 290 */       return true;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\ST\test\mod\com.st.stm32cube.ide.mcu.debug.launch_3.0.200.202210191513\!\com\st\stm32cube\ide\mcu\debug\launch\LoadListInfo.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.1.3
 */