/*     */ package com.st.stm32cube.ide.mcu.debug.launch.handler;
/*     */ 
/*     */ import com.st.stm32cube.common.logger.MCULoggerPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.MCUGdbLaunch;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.RestartListInfo;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.device.RestartStrategy;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collections;
/*     */ import java.util.function.Supplier;
/*     */ import java.util.stream.Collectors;
/*     */ import org.eclipse.core.runtime.CoreException;
/*     */ import org.eclipse.core.runtime.IAdaptable;
/*     */ import org.eclipse.debug.core.ILaunch;
/*     */ import org.eclipse.debug.core.ILaunchConfiguration;
/*     */ import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
/*     */ import org.eclipse.debug.ui.DebugUITools;
/*     */ import org.eclipse.jface.action.IContributionItem;
/*     */ import org.eclipse.swt.events.SelectionAdapter;
/*     */ import org.eclipse.swt.events.SelectionEvent;
/*     */ import org.eclipse.swt.events.SelectionListener;
/*     */ import org.eclipse.swt.widgets.Menu;
/*     */ import org.eclipse.swt.widgets.MenuItem;
/*     */ import org.eclipse.ui.actions.CompoundContributionItem;
/*     */ import org.eclipse.ui.handlers.IHandlerService;
/*     */ import org.eclipse.ui.menus.IWorkbenchContribution;
/*     */ import org.eclipse.ui.services.IServiceLocator;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class RestartContributionItem
/*     */   extends CompoundContributionItem
/*     */   implements IWorkbenchContribution
/*     */ {
/*     */   private IServiceLocator fServiceLocator;
/*     */   
/*     */   public void initialize(IServiceLocator serviceLocator) {
/*  47 */     this.fServiceLocator = serviceLocator;
/*     */   }
/*     */ 
/*     */   
/*     */   protected IContributionItem[] getContributionItems() {
/*  52 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void fill(Menu menu, int index) {
/*  58 */     MCUGdbLaunch gdbLaunch = getMCUGdbLaunch();
/*  59 */     if (gdbLaunch == null) {
/*     */       return;
/*     */     }
/*     */     
/*  63 */     ILaunchConfiguration launchConf = gdbLaunch.getLaunchConfiguration();
/*  64 */     if (launchConf == null) {
/*     */       return;
/*     */     }
/*     */     
/*  68 */     RestartListInfo restartListInfo = null;
/*     */     try {
/*  70 */       restartListInfo = RestartListInfo.parseRestartListInfo(launchConf).orElse(null);
/*  71 */     } catch (CoreException e) {
/*  72 */       MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to parse restart list information from the debug configuration");
/*     */       
/*     */       return;
/*     */     } 
/*  76 */     ArrayList<String> items = getItems(restartListInfo);
/*  77 */     Collections.reverse(items);
/*  78 */     for (String string : items) {
/*  79 */       MenuItem menuItem = new MenuItem(menu, 32, index);
/*  80 */       menuItem.setText(string);
/*  81 */       menuItem.addSelectionListener((SelectionListener)new MenuitemListener(launchConf));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private MCUGdbLaunch getMCUGdbLaunch() {
/*  90 */     MCUGdbLaunch gdbLaunch = null;
/*  91 */     IAdaptable debugContext = DebugUITools.getDebugContext();
/*  92 */     if (debugContext != null) {
/*  93 */       ILaunch launch = (ILaunch)debugContext.getAdapter(ILaunch.class);
/*  94 */       if (launch instanceof MCUGdbLaunch) {
/*  95 */         gdbLaunch = (MCUGdbLaunch)launch;
/*     */       }
/*     */     } 
/*  98 */     return gdbLaunch;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private ArrayList<String> getItems(RestartListInfo restartListInfo) {
/* 108 */     ArrayList<String> items = new ArrayList<>();
/* 109 */     ArrayList<RestartStrategy> restartStrategies = new ArrayList<>();
/* 110 */     if (restartListInfo != null) {
/* 111 */       restartStrategies = restartListInfo.getInternalItems();
/* 112 */       items = (ArrayList<String>)restartStrategies.stream().map(s -> s.getDisplayName()).collect(Collectors.toCollection(ArrayList::new));
/*     */     } 
/* 114 */     return items;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void updateHistory(ILaunchConfiguration launchConf, ArrayList<RestartStrategy> restartStrategies, RestartStrategy restartStrategy) {
/* 125 */     if (restartStrategies == null) {
/*     */       return;
/*     */     }
/* 128 */     restartStrategies.remove(restartStrategy);
/* 129 */     restartStrategies.add(0, restartStrategy);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void storeRestartListInLaunchConfiguration(ILaunchConfiguration launchConf, ArrayList<RestartStrategy> restartStrategies) {
/* 139 */     if (restartStrategies == null) {
/*     */       return;
/*     */     }
/*     */     try {
/* 143 */       ILaunchConfigurationWorkingCopy workingCopy = launchConf.getWorkingCopy();
/* 144 */       RestartListInfo restartListInfo = new RestartListInfo(restartStrategies);
/* 145 */       workingCopy.setAttribute(RestartListInfo.getRestartConfsAttributeName((ILaunchConfiguration)workingCopy), restartListInfo.asJSON());
/* 146 */       workingCopy.doSave();
/* 147 */     } catch (CoreException e) {
/* 148 */       MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to update debug configuration with the new restart configuraitons list");
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private class MenuitemListener
/*     */     extends SelectionAdapter
/*     */   {
/*     */     private ILaunchConfiguration fLaunchConf;
/*     */ 
/*     */ 
/*     */     
/*     */     public MenuitemListener(ILaunchConfiguration launch) {
/* 163 */       this.fLaunchConf = launch;
/*     */     }
/*     */ 
/*     */     
/*     */     public void widgetSelected(SelectionEvent event) {
/* 168 */       MenuItem menuItem = (MenuItem)event.widget;
/* 169 */       String restartName = menuItem.getText();
/*     */       
/* 171 */       RestartListInfo restartListInfo = null;
/*     */       try {
/* 173 */         restartListInfo = RestartListInfo.parseRestartListInfo(this.fLaunchConf).orElse(null);
/* 174 */         if (restartListInfo != null) {
/* 175 */           ArrayList<RestartStrategy> restartStrategies = restartListInfo.getInternalItems();
/* 176 */           RestartStrategy restartStrategy = RestartStrategy.find(restartName, restartStrategies, RestartStrategy.RestartStrategySearchKey.NAME);
/* 177 */           RestartContributionItem.this.updateHistory(this.fLaunchConf, restartStrategies, restartStrategy);
/* 178 */           RestartContributionItem.this.storeRestartListInLaunchConfiguration(this.fLaunchConf, restartStrategies);
/*     */           
/* 180 */           IHandlerService service = (IHandlerService)RestartContributionItem.this.fServiceLocator.getService(IHandlerService.class);
/*     */           try {
/* 182 */             service.executeCommand("com.st.stm32cube.ide.mcu.debug.launch.command.restartCommand", null);
/* 183 */           } catch (Exception e) {
/* 184 */             MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", e, "Failed to execute the restart command");
/*     */           } 
/*     */         } 
/* 187 */       } catch (CoreException e) {
/* 188 */         MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to parse restart list information from the debug configuration");
/*     */         return;
/*     */       } 
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\ST\test\mod\com.st.stm32cube.ide.mcu.debug.launch_3.0.200.202210191513\!\com\st\stm32cube\ide\mcu\debug\launch\handler\RestartContributionItem.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.1.3
 */