/*     */ package com.st.stm32cube.ide.mcu.debug.launch.export;
/*     */ 
/*     */ import com.st.stm32cube.common.ecosystemintegration.core.CpuCoreEnum;
/*     */ import com.st.stm32cube.common.logger.MCULoggerPlugin;
/*     */ import com.st.stm32cube.ide.common.utils.ThreadHelper;
/*     */ import com.st.stm32cube.ide.mcu.debug.MCUDebugPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.Activator;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.IMxUGDBServer;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.LoadListInfo;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.device.GDBServerContributionFactory;
/*     */ import com.st.stm32cube.ide.mcu.debug.swv.core.SWVPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.swv.core.SessionManager;
/*     */ import com.st.stm32cube.ide.mcu.debug.swv.core.SwvInfo;
/*     */ import com.st.stm32cube.ide.mcu.productdb.core.Core;
/*     */ import java.io.File;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Arrays;
/*     */ import java.util.Collections;
/*     */ import java.util.HashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Optional;
/*     */ import java.util.stream.Collectors;
/*     */ import org.eclipse.cdt.debug.core.CDebugUtils;
/*     */ import org.eclipse.cdt.debug.gdbjtag.core.jtagdevice.GDBJtagDeviceContribution;
/*     */ import org.eclipse.cdt.debug.gdbjtag.core.jtagdevice.IGDBJtagDevice;
/*     */ import org.eclipse.cdt.dsf.gdb.service.IGDBBackend;
/*     */ import org.eclipse.cdt.dsf.mi.service.command.output.MIInfo;
/*     */ import org.eclipse.cdt.dsf.mi.service.command.output.MIOOBRecord;
/*     */ import org.eclipse.cdt.dsf.mi.service.command.output.MIStreamRecord;
/*     */ import org.eclipse.cdt.dsf.mi.service.command.output.MITargetStreamOutput;
/*     */ import org.eclipse.cdt.dsf.service.DsfServicesTracker;
/*     */ import org.eclipse.cdt.dsf.service.DsfSession;
/*     */ import org.eclipse.cdt.utils.elf.ElfHelper;
/*     */ import org.eclipse.cdt.utils.spawner.ProcessFactory;
/*     */ import org.eclipse.core.runtime.CoreException;
/*     */ import org.eclipse.core.runtime.IPath;
/*     */ import org.eclipse.core.runtime.IStatus;
/*     */ import org.eclipse.core.runtime.Status;
/*     */ import org.eclipse.core.variables.VariablesPlugin;
/*     */ import org.eclipse.debug.core.DebugPlugin;
/*     */ import org.eclipse.debug.core.ILaunch;
/*     */ import org.eclipse.debug.core.ILaunchConfiguration;
/*     */ import org.eclipse.debug.core.model.IProcess;
/*     */ import org.eclipse.jface.dialogs.MessageDialog;
/*     */ import org.eclipse.swt.widgets.Display;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class HardwareDebugUtil
/*     */ {
/*     */   private static final String EMPTY_STRING = "";
/*     */   
/*     */   public static boolean checkConfigSupported(ILaunchConfiguration config) {
/*     */     try {
/*  73 */       int formatVersion = config.getAttribute("com.st.stm32cube.ide.mcu.debug.launch.formatVersion", 1);
/*  74 */       if (formatVersion < 2) {
/*  75 */         return false;
/*     */       }
/*  77 */     } catch (CoreException e) {
/*     */       
/*  79 */       return false;
/*     */     } 
/*     */     
/*  82 */     return true;
/*     */   }
/*     */ 
/*     */   
/*     */   public static void startServer(ILaunchConfiguration configuration, ILaunch launch) throws CoreException {
/*  87 */     String deviceId = getServerId(configuration).orElse("");
/*  88 */     GDBJtagDeviceContribution contribution = GDBServerContributionFactory.findById(deviceId);
/*  89 */     if (contribution != null) {
/*  90 */       IGDBJtagDevice device = contribution.getDevice();
/*  91 */       if (device instanceof IMxUGDBServer) {
/*  92 */         IMxUGDBServer server = (IMxUGDBServer)device;
/*     */         
/*  94 */         List<String> params = server.getServerStartArguments(configuration);
/*  95 */         startServer(contribution.getDeviceName(), server, params, launch);
/*     */       } 
/*     */     } 
/*     */   }
/*     */   
/*     */   public static Optional<String> getServerId(ILaunchConfiguration configuration) {
/*     */     try {
/* 102 */       String serverId = configuration.getAttribute("org.eclipse.cdt.debug.gdbjtag.core.jtagDeviceId", "");
/* 103 */       if (serverId.isEmpty()) {
/*     */         
/* 105 */         String serverName = configuration.getAttribute("org.eclipse.cdt.debug.gdbjtag.core.jtagDevice", "");
/* 106 */         if (!serverName.isEmpty()) {
/* 107 */           GDBJtagDeviceContribution jtagDeviceContrib = GDBServerContributionFactory.findByName(serverName);
/* 108 */           if (jtagDeviceContrib != null) {
/* 109 */             serverId = jtagDeviceContrib.getDeviceId();
/*     */           }
/*     */         } 
/*     */       } 
/* 113 */       return Optional.of(serverId);
/* 114 */     } catch (CoreException e) {
/* 115 */       MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to get server id from configuration");
/* 116 */       return Optional.empty();
/*     */     } 
/*     */   }
/*     */   
/*     */   public static Optional<IMxUGDBServer> getServer(ILaunchConfiguration configuration) {
/* 121 */     String deviceId = getServerId(configuration).orElse(null);
/* 122 */     if (deviceId != null) {
/* 123 */       return getServer(deviceId);
/*     */     }
/* 125 */     return Optional.empty();
/*     */   }
/*     */   
/*     */   public static Optional<IMxUGDBServer> getServer(String deviceId) {
/* 129 */     GDBJtagDeviceContribution contribution = GDBServerContributionFactory.findById(deviceId);
/* 130 */     if (contribution != null) {
/* 131 */       IGDBJtagDevice device = contribution.getDevice();
/* 132 */       if (device instanceof IMxUGDBServer) {
/* 133 */         return Optional.of((IMxUGDBServer)device);
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 138 */     MCULoggerPlugin.logErrorMessage("com.st.stm32cube.ide.mcu.debug.launch", "No such server: " + deviceId);
/* 139 */     return Optional.empty();
/*     */   }
/*     */ 
/*     */   
/*     */   public static void startServer(String deviceName, IMxUGDBServer serverToStart, List<String> cmdParams, ILaunch launch) throws CoreException {
/* 144 */     if (serverToStart == null) {
/* 145 */       Status status = new Status(4, "com.st.stm32cube.ide.mcu.debug.launch", Messages.HardwareDebugUtil_ERROR_CCppEmbeddedApplication_serverToStartIsNull);
/* 146 */       Activator.log((IStatus)status);
/* 147 */       throw new CoreException(status);
/*     */     } 
/*     */     
/* 150 */     boolean validExec = false;
/* 151 */     IProcess iProcess = null;
/*     */ 
/*     */     
/* 154 */     while (!validExec) {
/*     */       
/*     */       try {
/* 157 */         serverToStart.checkSTLinkServer(launch);
/*     */         
/* 159 */         List<String> command = new ArrayList<>();
/* 160 */         String serverExePath = serverToStart.getServerInstallLocation(launch.getLaunchConfiguration());
/* 161 */         String serverWcDir = serverToStart.getServerWorkingDir(launch.getLaunchConfiguration());
/* 162 */         command.add(serverExePath);
/* 163 */         command.addAll(cmdParams);
/*     */ 
/*     */ 
/*     */         
/* 167 */         Map<String, String> processEnvironment = (new ProcessBuilder(command)).environment();
/*     */         
/* 169 */         Map<String, String> serverEnviron = serverToStart.getServerStartEnvironment();
/* 170 */         processEnvironment.putAll(serverEnviron);
/*     */         
/* 172 */         List<String> environment = new ArrayList<>();
/* 173 */         for (Map.Entry<String, String> entry : processEnvironment.entrySet()) {
/* 174 */           environment.add(String.valueOf(entry.getKey()) + "=" + (String)entry.getValue());
/*     */         }
/*     */         
/* 177 */         Process server = ProcessFactory.getFactory().exec(command.<String>toArray(new String[command.size()]), environment.<String>toArray(new String[environment.size()]), new File(serverWcDir), 5000);
/*     */         
/* 179 */         Map<String, String> attributes = new HashMap<>();
/* 180 */         attributes.put("org.eclipse.cdt.dsf.gdb.createProcessType", "com.st.stm32cube.ide.mcu.debug.launch.gdbServerProcess");
/* 181 */         iProcess = DebugPlugin.newProcess(launch, server, deviceName, attributes);
/*     */         
/* 183 */         validExec = true;
/*     */       }
/* 185 */       catch (Exception e) {
/* 186 */         MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", e, Messages.HardwareDebugUtil_ERROR_launchinGdbServer_sessionTerminated);
/*     */ 
/*     */         
/* 189 */         Status status = new Status(4, "com.st.stm32cube.ide.mcu.debug.launch", Messages.HardwareDebugUtil_ERROR_launchinGdbServer_sessionTerminated, e);
/* 190 */         throw new CoreException(status);
/*     */       } 
/*     */     } 
/*     */     
/* 194 */     serverToStart.verifyServer(launch.getLaunchConfiguration(), iProcess);
/*     */   }
/*     */   
/*     */   public static List<String> toStringFromMonitorReply(MIInfo data) {
/* 198 */     if (data != null) {
/* 199 */       MIOOBRecord[] oob = data.getMIOutput().getMIOOBRecords();
/* 200 */       if (oob != null) {
/* 201 */         return (List<String>)Arrays.<MIOOBRecord>stream(oob)
/* 202 */           .filter(MITargetStreamOutput.class::isInstance)
/* 203 */           .map(MITargetStreamOutput.class::cast)
/* 204 */           .map(MIStreamRecord::getString)
/* 205 */           .map(String::trim)
/* 206 */           .collect(Collectors.toList());
/*     */       }
/*     */     } 
/* 209 */     return Collections.emptyList();
/*     */   }
/*     */   
/*     */   public static SwvInfo toSwvInfoFromStLink(String str) {
/* 213 */     String[] elements = str.split(";");
/* 214 */     if (elements.length >= 3) {
/*     */       try {
/* 216 */         int recommendedSwoLimit = Integer.parseInt(elements[0], 16) * 1000;
/* 217 */         int noDataSets = Integer.parseInt(elements[1], 16);
/* 218 */         if (elements.length - 2 == noDataSets) {
/* 219 */           SwvInfo swvInfo = new SwvInfo(recommendedSwoLimit);
/* 220 */           for (int i = 2; i < elements.length; i++) {
/* 221 */             String[] subelements = elements[i].split(",");
/* 222 */             if (subelements.length == 3) {
/* 223 */               swvInfo.addDataset((Integer.parseInt(subelements[0], 16) * 1000), 
/* 224 */                   Integer.parseInt(subelements[1], 16), Integer.parseInt(subelements[2], 16));
/*     */             } else {
/*     */               
/* 227 */               return null;
/*     */             } 
/*     */           } 
/* 230 */           return swvInfo;
/*     */         } 
/* 232 */       } catch (NumberFormatException numberFormatException) {}
/*     */     }
/*     */ 
/*     */     
/* 236 */     return null;
/*     */   }
/*     */ 
/*     */   
/*     */   public static void createSWVsession(ILaunchConfiguration config, DsfSession session, SwvInfo.SwvConfig swvConfig) throws CoreException {
/*     */     try {
/* 242 */       String port = config.getAttribute("com.st.stm32cube.ide.mcu.debug.launch.swv_port", "0");
/* 243 */       String host = config.getAttribute("org.eclipse.cdt.debug.gdbjtag.core.ipAddress", "localhost");
/*     */ 
/*     */       
/* 246 */       LoadListInfo loadListInfo = LoadListInfo.parseLoadListInfo(config.getAttributes()).orElse(null);
/*     */       
/* 248 */       List<ElfHelper> loadedObjs = new ArrayList<>();
/* 249 */       if (loadListInfo != null) {
/* 250 */         for (LoadListInfo.LoadListItem item : loadListInfo.getInternalItems()) {
/* 251 */           if (item.shouldLoadSymbols().booleanValue()) {
/* 252 */             loadedObjs.add(new ElfHelper(item.getAbsolutePath()));
/*     */           }
/*     */         }
/*     */       
/*     */       } else {
/*     */         
/* 258 */         Map<String, Object> attributes = config.getAttributes();
/* 259 */         if (((Boolean)CDebugUtils.getAttribute(attributes, "org.eclipse.cdt.debug.gdbjtag.core.loadSymbols", Boolean.valueOf(true))).booleanValue()) {
/* 260 */           String symbolsFileName = null;
/*     */           
/* 262 */           DsfServicesTracker tracker = new DsfServicesTracker(MCUDebugPlugin.getBundleContext(), session.getId());
/* 263 */           IGDBBackend fGDBBackend = (IGDBBackend)tracker.getService(IGDBBackend.class);
/* 264 */           tracker.dispose();
/*     */           
/* 266 */           if (fGDBBackend != null) {
/* 267 */             if (attributes.containsKey("org.eclipse.cdt.debug.gdbjtag.core.useProjBinaryForSymbols") && ((Boolean)CDebugUtils.getAttribute(attributes, "org.eclipse.cdt.debug.gdbjtag.core.useProjBinaryForSymbols", Boolean.valueOf(true))).booleanValue()) {
/* 268 */               IPath programFile = fGDBBackend.getProgramPath();
/*     */               
/* 270 */               if (programFile != null) {
/* 271 */                 symbolsFileName = programFile.toString();
/*     */               }
/*     */             } else {
/*     */               
/* 275 */               symbolsFileName = (String)CDebugUtils.getAttribute(attributes, "org.eclipse.cdt.debug.gdbjtag.core.symbolsFileName", "");
/* 276 */               if (symbolsFileName.length() > 0) {
/* 277 */                 symbolsFileName = VariablesPlugin.getDefault().getStringVariableManager().performStringSubstitution(symbolsFileName);
/*     */               } else {
/* 279 */                 symbolsFileName = null;
/*     */               } 
/*     */             } 
/*     */             
/* 283 */             if (symbolsFileName != null) {
/* 284 */               loadedObjs.add(new ElfHelper(symbolsFileName));
/*     */             }
/*     */           } 
/*     */         } 
/*     */       } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 294 */       SessionManager swvSessionManager = SWVPlugin.getDefault().getSessionManager();
/* 295 */       if (!swvSessionManager.createSession(config, session, host, port, swvConfig, loadedObjs)) {
/* 296 */         ThreadHelper.runInUiThreadAsync(() -> MessageDialog.openWarning(Display.getDefault().getActiveShell(), Messages.HardwareDebugUtil_WARNING_SwvCreateSessionFailedTitle, Messages.HardwareDebugUtil_WARNING_SwvCreateSessionFailed));
/*     */       }
/* 298 */     } catch (Exception e) {
/*     */       
/* 300 */       throw new CoreException(new Status(4, "com.st.stm32cube.ide.mcu.debug.launch", Messages.HardwareDebugUtil_ERROR_SwvConnectionFailed, e));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isSwvSupported(Core core) {
/* 311 */     if (core != null) {
/* 312 */       switch (core.getCpuCore()) {
/*     */         case Cortex_M3:
/*     */         case Cortex_M4:
/*     */         case Cortex_M7:
/*     */         case Cortex_M33:
/* 317 */           return true;
/*     */       } 
/*     */ 
/*     */ 
/*     */     
/*     */     }
/* 323 */     return false;
/*     */   }
/*     */ }


/* Location:              C:\ST\test\ori\com.st.stm32cube.ide.mcu.debug.launch_3.0.200.202210191513.jar!\com\st\stm32cube\ide\mcu\debug\launch\export\HardwareDebugUtil.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.1.3
 */