/*     */ package com.st.stm32cube.ide.mcu.debug.launch.handler;
/*     */ 
/*     */ import com.st.stm32cube.common.logger.MCULoggerPlugin;
/*     */ import com.st.stm32cube.common.projectcreation.core.ProjectUtilities;
/*     */ import com.st.stm32cube.ide.mcu.debug.MCUDebugPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.service.restart.IRestartService;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.ui.TabHelper;
/*     */ import com.st.stm32cube.ide.mpu.projectnatures.core.MPUEmbeddedMCUProjectNature;
/*     */ import java.util.Optional;
/*     */ import java.util.concurrent.Executor;
/*     */ import org.eclipse.cdt.dsf.concurrent.DataRequestMonitor;
/*     */ import org.eclipse.cdt.dsf.concurrent.DsfExecutor;
/*     */ import org.eclipse.cdt.dsf.concurrent.RequestMonitor;
/*     */ import org.eclipse.cdt.dsf.datamodel.DMContexts;
/*     */ import org.eclipse.cdt.dsf.debug.service.command.ICommandControlService;
/*     */ import org.eclipse.cdt.dsf.debug.ui.actions.DsfCommandRunnable;
/*     */ import org.eclipse.cdt.dsf.service.DsfServicesTracker;
/*     */ import org.eclipse.cdt.dsf.service.DsfSession;
/*     */ import org.eclipse.cdt.dsf.ui.viewmodel.datamodel.IDMVMContext;
/*     */ import org.eclipse.core.resources.IProject;
/*     */ import org.eclipse.core.runtime.CoreException;
/*     */ import org.eclipse.debug.core.ILaunch;
/*     */ import org.eclipse.debug.core.ILaunchConfiguration;
/*     */ import org.eclipse.debug.core.commands.IDebugCommandRequest;
/*     */ import org.eclipse.debug.core.commands.IEnabledStateRequest;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DSFRestartHandler
/*     */   implements IRestartHandler
/*     */ {
/*     */   private final DsfExecutor fExecutor;
/*     */   private final DsfSession fSession;
/*     */   private final ILaunch fLaunch;
/*     */   
/*     */   public DSFRestartHandler(DsfSession session, ILaunch launch) {
/*  49 */     this.fSession = session;
/*  50 */     this.fExecutor = this.fSession.getExecutor();
/*  51 */     this.fLaunch = launch;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void canExecute(final IEnabledStateRequest request) {
/*  62 */     final DsfServicesTracker tracker = new DsfServicesTracker(MCUDebugPlugin.getBundleContext(), this.fSession.getId());
/*  63 */     this.fExecutor.submit((Runnable)new DsfCommandRunnable(tracker, request.getElements()[0], (IDebugCommandRequest)request)
/*     */         {
/*     */           protected void doExecute() {
/*  66 */             IRestartService funcService = (IRestartService)tracker.getService(IRestartService.class);
/*  67 */             if (funcService == null) {
/*  68 */               request.setEnabled(false);
/*  69 */               request.done();
/*     */ 
/*     */               
/*     */               return;
/*     */             } 
/*     */ 
/*     */             
/*  76 */             ILaunchConfiguration launchConfiguration = DSFRestartHandler.this.fLaunch.getLaunchConfiguration();
/*  77 */             TabHelper tabHelper = new TabHelper();
/*     */             try {
/*  79 */               if (launchConfiguration != null) {
/*  80 */                 IProject project = tabHelper.getProject(launchConfiguration);
/*  81 */                 if (project != null) {
/*  82 */                   boolean hasNature = !(!ProjectUtilities.hasProjectNature(project, MPUEmbeddedMCUProjectNature.NATURE_ID) && 
/*  83 */                     !ProjectUtilities.hasProjectNature(project, "com.st.stm32cube.ide.mpu.MPUProjectNature"));
/*  84 */                   if (hasNature) {
/*  85 */                     request.setEnabled(false);
/*  86 */                     request.done();
/*     */                     return;
/*     */                   } 
/*     */                 } 
/*     */               } 
/*  91 */             } catch (CoreException e) {
/*  92 */               MCULoggerPlugin.logException(MCUDebugPlugin.getUniqueIdentifier(), (Throwable)e);
/*     */             } 
/*     */             
/*  95 */             funcService.canDoRestart(getContext(), new DataRequestMonitor<Boolean>((Executor)DSFRestartHandler.this.fExecutor, null)
/*     */                 {
/*     */                   protected void handleCompleted() {
/*  98 */                     request.setEnabled((isSuccess() && ((Boolean)getData()).booleanValue()));
/*  99 */                     request.done();
/*     */                   }
/*     */                 });
/*     */           }
/*     */         });
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean execute(final IDebugCommandRequest request) {
/* 114 */     Optional<ICommandControlService.ICommandControlDMContext> context = getContext(request);
/* 115 */     if (!context.isPresent()) {
/* 116 */       request.done();
/* 117 */       return false;
/*     */     } 
/*     */     
/* 120 */     DsfServicesTracker tracker = new DsfServicesTracker(MCUDebugPlugin.getBundleContext(), this.fSession.getId());
/* 121 */     IRestartService funcService = (IRestartService)tracker.getService(IRestartService.class);
/* 122 */     tracker.dispose();
/* 123 */     funcService.doRestart(context.get(), request, this.fLaunch, new RequestMonitor((Executor)this.fExecutor, null)
/*     */         {
/*     */           protected void handleCompleted() {
/* 126 */             if (!request.isCanceled()) {
/* 127 */               request.done();
/*     */             }
/*     */           }
/*     */         });
/* 131 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Optional<ICommandControlService.ICommandControlDMContext> getContext(IDebugCommandRequest request) {
/* 140 */     if ((request.getElements()).length != 1 || !(request.getElements()[0] instanceof IDMVMContext)) {
/* 141 */       return Optional.empty();
/*     */     }
/*     */     
/* 144 */     IDMVMContext context = (IDMVMContext)request.getElements()[0];
/* 145 */     ICommandControlService.ICommandControlDMContext controlDmc = (ICommandControlService.ICommandControlDMContext)DMContexts.getAncestorOfType(context.getDMContext(), ICommandControlService.ICommandControlDMContext.class);
/* 146 */     if (controlDmc != null) {
/* 147 */       return Optional.of(controlDmc);
/*     */     }
/* 149 */     return Optional.empty();
/*     */   }
/*     */ }


/* Location:              C:\ST\test\ori\com.st.stm32cube.ide.mcu.debug.launch_3.0.200.202210191513.jar!\com\st\stm32cube\ide\mcu\debug\launch\handler\DSFRestartHandler.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.1.3
 */