/*     */ package com.st.stm32cube.ide.mcu.debug.launch.service.restart;
/*     */ 
/*     */ import com.st.stm32cube.common.logger.MCULoggerPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.MCUDebugPlugin;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.MCUGdbLaunch;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.RestartListInfo;
/*     */ import com.st.stm32cube.ide.mcu.debug.launch.device.RestartStrategy;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Hashtable;
/*     */ import java.util.concurrent.Executor;
/*     */ import org.eclipse.cdt.dsf.concurrent.DataRequestMonitor;
/*     */ import org.eclipse.cdt.dsf.concurrent.DsfExecutor;
/*     */ import org.eclipse.cdt.dsf.concurrent.ImmediateExecutor;
/*     */ import org.eclipse.cdt.dsf.concurrent.ImmediateRequestMonitor;
/*     */ import org.eclipse.cdt.dsf.concurrent.RequestMonitor;
/*     */ import org.eclipse.cdt.dsf.debug.service.IRunControl;
/*     */ import org.eclipse.cdt.dsf.debug.service.command.ICommandControlService;
/*     */ import org.eclipse.cdt.dsf.service.AbstractDsfService;
/*     */ import org.eclipse.cdt.dsf.service.DsfSession;
/*     */ import org.eclipse.core.runtime.CoreException;
/*     */ import org.eclipse.debug.core.ILaunch;
/*     */ import org.eclipse.debug.core.ILaunchConfiguration;
/*     */ import org.eclipse.debug.core.commands.IDebugCommandRequest;
/*     */ import org.osgi.framework.BundleContext;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class RestartService
/*     */   extends AbstractDsfService
/*     */   implements IRestartService
/*     */ {
/*  38 */   private DsfSession fSession = null;
/*     */ 
/*     */   
/*     */   private DsfExecutor fExecutor;
/*     */ 
/*     */   
/*     */   private IRunControl fRunControl;
/*     */ 
/*     */ 
/*     */   
/*     */   public RestartService(DsfSession session) {
/*  49 */     super(session);
/*  50 */     this.fSession = session;
/*  51 */     this.fExecutor = this.fSession.getExecutor();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void initialize(final RequestMonitor rm) {
/*  62 */     super.initialize((RequestMonitor)new ImmediateRequestMonitor(rm)
/*     */         {
/*     */           protected void handleSuccess() {
/*  65 */             RestartService.this.doInitialize(rm);
/*     */           }
/*     */         });
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void doInitialize(RequestMonitor rm) {
/*  76 */     register(new String[] { IRestartService.class.getName() }, new Hashtable<>());
/*  77 */     rm.done();
/*     */   }
/*     */ 
/*     */   
/*     */   public void shutdown(RequestMonitor rm) {
/*  82 */     unregister();
/*  83 */     super.shutdown(rm);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void canDoRestart(IRunControl.IExecutionDMContext ctx, DataRequestMonitor<Boolean> rm) {
/*  93 */     rm.done(Boolean.valueOf(true));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void doRestart(ICommandControlService.ICommandControlDMContext ctx, final IDebugCommandRequest request, ILaunch launch, RequestMonitor rm) {
/* 105 */     if (launch instanceof MCUGdbLaunch) {
/* 106 */       MCUGdbLaunch gdbLaunch = (MCUGdbLaunch)launch;
/* 107 */       ILaunchConfiguration launchConf = gdbLaunch.getLaunchConfiguration();
/* 108 */       if (launchConf != null) {
/* 109 */         RestartListInfo restartListInfo = null;
/*     */         try {
/* 111 */           restartListInfo = RestartListInfo.parseRestartListInfo(launchConf).orElse(null);
/* 112 */         } catch (CoreException e) {
/* 113 */           MCULoggerPlugin.logException("com.st.stm32cube.ide.mcu.debug.launch", (Throwable)e, "Failed to parse restart list information from the debug configuration");
/* 114 */           rm.done();
/*     */           
/*     */           return;
/*     */         } 
/* 118 */         ArrayList<RestartStrategy> restartStrategies = new ArrayList<>();
/* 119 */         if (restartListInfo != null) {
/* 120 */           restartStrategies = restartListInfo.getInternalItems();
/*     */         }
/* 122 */         if (restartStrategies.isEmpty()) {
/*     */           
/* 124 */           IRestartConfigurationsService restartConfService = (IRestartConfigurationsService)getServicesTracker().getService(IRestartConfigurationsService.class);
/* 125 */           if (restartConfService != null) {
/* 126 */             restartConfService.doRestartConfigurations(ctx, request, (ILaunch)gdbLaunch, new RequestMonitor((Executor)this.fExecutor, null)
/*     */                 {
/*     */                   protected void handleCompleted() {
/* 129 */                     if (!request.isCanceled()) {
/* 130 */                       request.done();
/*     */                     }
/*     */                   }
/*     */                 });
/*     */           }
/*     */         } else {
/* 136 */           doRestartSequence(gdbLaunch, restartStrategies.get(0), rm, request);
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void doRestartSequence(MCUGdbLaunch gdbLaunch, RestartStrategy restartStrategy, RequestMonitor rm, IDebugCommandRequest request) {
/* 153 */     RestartServiceSequence gdbRestartSeq = new RestartServiceSequence((ILaunch)gdbLaunch, this.fSession, restartStrategy, rm, request);
/*     */     
/* 155 */     ImmediateExecutor.getInstance().execute((Runnable)gdbRestartSeq);
/*     */   }
/*     */ 
/*     */   
/*     */   protected BundleContext getBundleContext() {
/* 160 */     return MCUDebugPlugin.getBundleContext();
/*     */   }
/*     */ }


/* Location:              C:\ST\test\ori\com.st.stm32cube.ide.mcu.debug.launch_3.0.200.202210191513.jar!\com\st\stm32cube\ide\mcu\debug\launch\service\restart\RestartService.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.1.3
 */